OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日曆",
    "Individual" : "個人",
    "Group" : "群組",
    "Resource" : "資源",
    "Room" : "房間",
    "Unknown" : "未知",
    "Required" : "必填",
    "Optional" : "選填",
    "Does not attend" : "不參加",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "未知的時區設定({tz})，返回標準時區(UTC)",
    "Please create a calendar first." : "請先建立一個日曆。",
    "New event" : "新活動",
    "Attendees" : "出席者",
    "Reminders" : "提醒",
    "Repeating" : "重覆中",
    "When shared show full event" : "分享的時候顯示完整活動",
    "When shared hide this event" : "分享的時候隱藏這個活動",
    "Please add a title!" : "請加入標題！",
    "Please select a calendar!" : "請選擇一個日曆！",
    "Global" : "全域",
    "None" : "無",
    "Every day" : "每天",
    "Every week" : "每週",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "永不",
    "after" : "之後",
    "At time of event" : "活動當時",
    "5 minutes before" : "5 分鐘前",
    "10 minutes before" : "10 分鐘前",
    "15 minutes before" : "15 分鐘前",
    "30 minutes before" : "30 分鐘前",
    "1 hour before" : "1 小時前",
    "2 hours before" : "2 小時前",
    "Custom" : "自訂",
    "Audio" : "音訊",
    "E Mail" : "電子郵件",
    "Pop up" : "彈出視窗",
    "sec" : "秒",
    "min" : "分",
    "hours" : "時",
    "days" : "天",
    "week" : "週",
    "before" : "前",
    "start" : "開始",
    "end" : "結束",
    "Week {number} of {year}" : "{year} 的第 {number} 週",
    "Successfully imported" : "成功匯入",
    "Partially imported, 1 failure" : "部分匯入，1 個失敗",
    "Partially imported, {n} failures" : "部分匯入，{n} 個失敗",
    "Audio alarm" : "聲音提醒",
    "Pop-up" : "彈出視窗",
    "E-Mail" : "電子郵件",
    "{type} {time} before the event starts" : "{type} 活動開始前 {time}",
    "{type} {time} before the event ends" : "{type} 活動結束前 {time}",
    "{type} {time} after the event starts" : "{type} 活動開始後 {time}",
    "{type} {time} after the event ends" : "{type} 活動開始前 {time}",
    "{type} at the event's start" : "{type} 活動開始時",
    "{type} at the event's end" : "{type} 活動結束時",
    "{type} at {time}" : "{type} 在 {time}",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 分享",
    "Title of the Event" : "活動標題",
    "starts" : "開始",
    "ends" : "結束",
    "All day Event" : "全天活動",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "More ..." : "更多…",
    "Create" : "建立",
    "Update" : "更新",
    "Close" : " 關閉",
    "Location" : "地點",
    "Description" : "描述",
    "Export" : "匯出",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "上傳錯誤，目前不支援asset pipeline功能。",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "請聯絡系統管理員，於設定檔中關閉\"asset-pipeline.enabled\" 選項。",
    "Day" : "日",
    "Week" : "週",
    "Month" : "月",
    "Today" : "今天",
    "Share Calendar" : "分享日曆",
    "More" : "更多",
    "Edit" : "編輯",
    "Share with users or groups" : "與使用者和群組分享",
    "can edit" : "可編輯",
    "group" : "群組",
    "New Calendar" : "新日曆",
    "Subscriptions" : "訂閱",
    "New Subscription" : "新訂閱",
    "Url" : "網址",
    "Edit event" : "編輯活動",
    "Delete Event" : "刪除活動",
    "Save Event" : "儲存活動",
    "Time" : "時間",
    "Type" : "類型",
    "Relative" : "相對",
    "Absolute" : "絕對",
    "Repeat" : "重覆",
    "times every" : "次每",
    "Add" : "增加",
    "E-Mail address of attendee" : "參加者的 email",
    "Please add your email address in the personal settings in order to add attendees." : "請在個人設定頁面中設定您的 email 地址，才能新增參加者",
    "from" : "從",
    "to" : "至",
    "This event's repeating rule is not supported yet." : "還未支援此活動的重複規則",
    "Support for advanced rules will be added with subsequent updates." : "進階的規則功能將會在未來的更新加入",
    "Reset repeating rule" : "重設重複規則",
    "Repeat every ..." : "重複循環：",
    "end repeat ..." : "停止重複：",
    "times" : "次",
    "Import Calendars" : "匯入日曆",
    "Import canceled" : "已取消匯入",
    "Analyzing calendar" : "分析日曆",
    "The file contains objects incompatible with the selected calendar" : "這個檔案包含與選取的日曆不相容的物件",
    "New calendar" : "新日曆",
    "Import scheduled" : "已排程匯入",
    "Settings" : "設定",
    "Import calendar" : "匯入日曆",
    "No Calendars selected for import" : "沒有選擇要匯入的日曆",
    "Primary CalDAV address" : "主要的 CalDAV 地址",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV 地址"
},
"nplurals=1; plural=0;");
